#!/bin/bash 
#
# autotag -- for each disk in UNTAGGED, query CDDB,
# and if successful, rename and id3tag its mp3 files.
# Stephen Crane, April 2001
#
PATH=/usr/local/bin:$PATH
dir=`dirname $0`
etcdir=`dirname $dir`/etc
. $etcdir/riprc
queries=`ls $UNTAGGED/*/query 2>/dev/null`

if [ "$1" = "stop" ]; then
    touch $RIPDIR/stop
    exit
fi

for q in $queries; do
    disc=`dirname $q`
    if [[ -e $q && ! -e $disc/info ]]; then
	echo "Looking up $q"
	cddb_lookup $q 
    fi
done

if [ -e $RIPDIR/running ]; then
    echo "Autotag already running: PID("`cat $RIPDIR/running`")"
    exit
fi
echo $$ > $RIPDIR/running

trap "rm $RIPDIR/running" EXIT

discs=`ls -rt $UNTAGGED/*/info 2>/dev/null`
#echo "Discs: $discs"
while [ "$discs" != "" ]; do
    for info in $discs; do
	disc=`dirname $info`
	discid=`basename $disc`
	artisttitle=`grep ^DTITLE= $info | cut -f2 -d= | sed 's- / -~-g'`
	artist=`echo $artisttitle | cut -f1 -d~ | tr -d \[:cntrl:\] | tr -d \'\?`
	title=`echo $artisttitle | cut -f2 -d~ | tr -d \[:cntrl:\] | tr -d \[:cntrl:\] | tr -d \'\?`
	fartist=`echo $artist | tr \ / __`
	ftitle=`echo $title | tr \ / __`
	album=$ENCODED/$fartist/$ftitle
	mkdir -p $album
	tracks=`grep -e ^TTITLE $info | wc -l`
	track=0
	while [ $track -lt $tracks ]; do
	    if [ -e $RIPDIR/stop ]; then
		rm -f $RIPDIR/stop
		echo "Stopping tagging by request"
		exit
	    fi
	    index=$track
	    track=`expr $track + 1`
	    tid=$track
	    if [ $tid -lt 10 ]; then
		tid="0"$tid
	    fi
	    if [ -e $UNTAGGED/$discid/${tid}.wav ]; then
		name=`grep ^TTITLE${index}= $info | cut -f2 -d= | tr -d \[:cntrl:\]`
		fname=`echo $name | sed 's-\"-\\"-g' | tr -d \[:cntrl:\] | tr \ / __ | tr -d \'\?`
		file=${tid}-${fname}.mp3
		date=`grep ^EXTD= $info | perl -ne '/year:\s+(\d+)/i && print $1'`
		if [ "$date" != "" ]; then
		    date="--ty "$date
		fi
		genre=`grep ^EXTD= $info | perl -ne '/id3g:\s+(\d+)/i && print $1'`
		if [ "$genre" != "" ]; then
		    genre="--tg "$genre
		fi
		#echo lame $ENCODEOPTS --tt '"'"$name"'"' --ta '"'"$artist"'"' --tl '"'"$title"'"' --tn '"'"$track"'"' $date $genre $UNTAGGED/$discid/${tid}.wav $file  >> /tmp/lame.cmd
		nice -n 15 lame $ENCODEOPTS --tt "$name" --ta "$artist" --tl "$title" --tn "$track" $date $genre $UNTAGGED/$discid/${tid}.wav $UNTAGGED/$discid/$file
		if [ $? -eq 0 ]; then
		    mv $UNTAGGED/$discid/$file $album/$file
		    if [ $? -eq 0 ]; then
			rm -f $UNTAGGED/$discid/${tid}.wav
		    fi
		fi
	    fi
	done
	if [ `ls -1 $UNTAGGED/$discid/ | grep -c wav\$` -eq 0 ]; then
	    mv $UNTAGGED/$discid $album/.cddb_info
	fi
    done
    discs=`ls $UNTAGGED/*/info 2>/dev/null`
    #echo "Discs: $discs"
done


